@@ -174,6 +174,7 @@ class TTreeMethods(object):
     _copycontext = True
 
     _vector_regex = re.compile(b"^vector<(.+)>$")
+    _objectpointer_regex = re.compile(b"\((.*)\)")
 
     def _attachstreamer(self, branch, streamer, streamerinfosmap, isTClonesArray):
         if streamer is None:
@@ -227,6 +228,9 @@ class TTreeMethods(object):
         elif isinstance(streamer, digDeeperTypes):
             typename = streamer._fTypeName.rstrip(b"*")
             if typename in streamerinfosmap:
+                m = self._objectpointer_regex.search(streamer._fTitle)
+                if typename == b'TClonesArray' and m is not None:
+                    typename = m.group(1)
                 members = streamerinfosmap[typename].members
         elif isinstance(streamer, uproot.rootio.TStreamerSTL):
             try:
@@ -1271,7 +1275,7 @@ class TBranchMethods(object):
         entrystart, entrystop = self._normalize_entrystartstop(entrystart, entrystop)
         basketstart, basketstop = self._basketstartstop(entrystart, entrystop)
 
-        if self._source.parent() is not None:
+        if basketstart is not None and basketstop is not None and self._source.parent() is not None:
             self._source.parent().preload([self._fBasketSeek[i] for i in range(basketstart, basketstop)])
 
         if cache is not None:
